@@ -1,5 +1,10 @@
+from __future__ import print_function
 import requests
-from urllib import urlencode
+try:
+    from urllib import urlencode, quote_plus
+except ImportError:
+    from urllib.parse import urlencode, quote_plus
+
 from pprint import pprint
 
 try:
@@ -18,6 +23,10 @@ def get_version():
         return "%s.%s.%s" % __version__
 
 
+def _utf8_encode(component):
+    return component.encode("utf-8")
+
+
 class ESClientException(Exception):
     pass
 
@@ -57,7 +66,8 @@ class ESClient:
         ignored.
 
         """
-        path_components = map(str, filter(None, path_components))
+        path_components = map(_utf8_encode, filter(None, path_components))
+        path_components = map(quote_plus, path_components)
         path = '/'.join(path_components)
         if not path.startswith('/'):
             path = '/' + path
@@ -546,6 +556,14 @@ class ESClient:
         self.send_request('PUT', path=path, body=mapping)
         return self._parse_json_response(self.last_response.text)
 
+    #Cluster related API
+
+    def get_health(self, indexes=[]):
+        path = self._make_path(['_cluster', 'health', ','.join(indexes)])
+        self.send_request('GET', path=path)
+        resp = json.loads(self.last_response.text)
+        return resp["status"]
+
 
 if __name__ == '__main__':
-    print "This is a library, it is not intended to be started by itself."
+    print("This is a library, it is not intended to be started by itself.")
